==> mgb-0.5.3-de.zip: mgb-0.5.3-de/gbinfo.php <==
<?php
         // MGB v.null.fnf (C) by Jrgen Grneisl
         //
         // This Guestbook is licensed under GNU GPL. Feel free to use, copy, share or modify it. :)

         if($settings['spam']==1)
                 {
                 $info.="<div><font>".$lang['spamprotection'].": <b>".$lang['active']."</b></font></div>";
                 }
         else
                 {
                 $info.="<div><font>".$lang['spamprotection'].": <b>".$lang['inactive']."</b></font></div>";
                 }
         if($settings['smilies']==1)
                 {
                 $info.="<div><font>".$lang['smilies'].": <b>".$lang['active']."</b></font></div>";
                 }
         else
                 {
                 $info.="<div><font>".$lang['smilies'].": <b>".$lang['inactive']."</b></font></div>";
                 }
         if($settings['zensur']!="")
                 {
                 $info.="<div><font>".$lang['censorship'].": <b>".$lang['active']."</b></font></div>";
                 }
         else
                 {
                 $info.="<div><font>".$lang['censorship'].": <b>".$lang['inactive']."</b></font></div>";
                 }
         if($settings['quakemessage']==1)
                 {
                 $info.="<div><font>".$lang['quakemessage'].": <b>".$lang['active']."</b></font></div>";
                 }
         else
                 {
                 $info.="<div><font>".$lang['quakemessage'].": <b>".$lang['inactive']."</b></font></div>";
                 }
?>
<div style="padding:7px">
<center>
	<div style="border:none">
         <?php
         	echo $info;
         ?>
         </div>
</center>
</div>

==> mgb-0.5.4-de.zip: mgb-0.5.4-de/gbinfo.php <==
<?php
// DO NOT REMOVE THIS COPYRIGHT //
//
// MGB v.null.fuenf (0.5.4) (C) by Jrgen Grneisl
// Visit me on http://www.tv-kritik.net/mgb/index.php
//
// This Guestbook is licensed under GNU GPL. Feel free to use, copy, share or modify it. :)

         if($settings['spam']==1)
                 {
                 $info.="<div><font>".$lang['spamprotection'].": <b>".$lang['active']."</b></font></div>";
                 }
         else
                 {
                 $info.="<div><font>".$lang['spamprotection'].": <b>".$lang['inactive']."</b></font></div>";
                 }
	if($settings['smilies']==1)
                 {
                 $info.="<div><font>".$lang['smilies'].": <b>".$lang['active']."</b></font></div>";
                 }
         else
                 {
                 $info.="<div><font>".$lang['smilies'].": <b>".$lang['inactive']."</b></font></div>";
                 }
	if($settings['bbcodes']==1)
                 {
                 $info.="<div><font>".$lang['bbcode'].": <b>".$lang['active']."</b></font></div>";
                 }
         else
                 {
                 $info.="<div><font>".$lang['bbcode'].": <b>".$lang['inactive']."</b></font></div>";
                 }
         if($settings['zensur']!="")
                 {
                 $info.="<div><font>".$lang['censorship'].": <b>".$lang['active']."</b></font></div>";
                 }
         else
                 {
                 $info.="<div><font>".$lang['censorship'].": <b>".$lang['inactive']."</b></font></div>";
                 }
?>
<div style="padding:7px">
<center>
	<div style="border:none">
         <?php
         	echo $info;
         ?>
         </div>
</center>
</div>
